@@ -1,7 +1,7 @@
 use 5.20.0;
 
 package Map::Metro::Standard::Moops {
-$Map::Metro::Standard::Moops::VERSION = '0.1700';
+$Map::Metro::Standard::Moops::VERSION = '0.1701';
 use base 'Moops';
     use List::AllUtils();
     use experimental();
@@ -20,7 +20,7 @@ use base 'Moops';
             'String::Trim'      => ['trim'],
             'feature'           => [qw/:5.20/],
             'experimental'      => [qw/postderef/],
-            'Map::Metro::Types' => ['-types'],
+            'Map::Metro::Types' => [{ replace => 1 }, '-types'],
             'List::Compare'     => [],
             'MooseX::SetOnce'   => [],
         );
